==> qt-creator-opensource-src-4.2.0.zip: qt-creator-opensource-src-4.2.0/src/libs/qtcreatorcdbext/pyfield.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <Python.h>

#include <string>

struct Field
{
    PyObject_HEAD
    const char *m_name; // owned
    bool m_initialized;
    unsigned long m_typeId;
    unsigned long m_offset;
    unsigned long m_parentTypeId;
    ULONG64 m_module;
};

PyTypeObject *field_pytype();

void initField(Field *field);
bool initTypeAndOffset(Field *field);

==> qt-creator-opensource-src-7.0.2.zip: qt-creator-opensource-src-7.0.2/src/libs/qtcreatorcdbext/pyfield.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <string>
#include <vector>

#include <Python.h>

class PyType;
struct PyFieldPrivate;

class PyField
{
public:
    PyField(std::string name, const PyType &parentType);
    std::string name() const ;
    const PyType &type() const;
    const PyType &parentType() const;
    ULONG64 bitsize() const;
    ULONG64 bitpos() const;

    bool isValid() const;

private:
    PyFieldPrivate *d = nullptr;
};

using PyFields = std::vector<PyField>;

struct FieldPythonObject
{
    PyObject_HEAD
    PyField *impl;
};

PyTypeObject *field_pytype();
PyObject *createPythonObject(PyField typeClass);
